==> fluxbox-0.9.13.tar.bz2: fluxbox-0.9.13/nls/fr_FR/Translation.m <==
$ codeset=ISO-8859-15

$set 1 #Align

1 En bas au centre
2 En bas  gauche
3 En bas  droite
4 Horizontal
6 A gauche en bas
7 A gauche au centre
8 A gauche en Haut
11 A droite en bas
12 A droite au centre
13 A droite en haut
14 En haut au centre
15 En haut  gauche
16 En haut  droite
17 Vertical

$set 2 #BaseDisplay


$set 3 #Common

2 Masquer automatiquement

$set 4 #Configmenu

2 Premier plan automatique
4 Cliquer pour converger
7 Convergence de la dernire fentre
8 Mode de convergence
9 Convergence de la nouvelle fentre
10 Maximization complte
11 Lissage d'images
12 Dplacement opaque des fentres
13 Focus semi-stupide
14 Convergence souple
15 Workspace Warping

$set 5 #Ewmh


$set 6 #FbTkError


$set 7 #Fluxbox


$set 8 #Gnome


$set 9 #Keys


$set 10 #Menu

3 Sortie
4 Icones
7 Disposition
9 Redmarrer
10 xterm

$set 11 #Remember


$set 12 #Screen

2 L: %4d x H: %4d
5 X: %4d x Y: %4d
6 0: 0000 x 0: 0000

$set 13 #Slit

4 Orientation du Slit
7 Disposition du Slit
8 Slit

$set 14 #Toolbar

1 Bptme du bureau courant
10 Disposition de la barre d'outils
11 Barre d'outils

$set 15 #Window

1 Inconnu

$set 16 #Windowmenu

1 Fermer
2 Iconifier
4 Baisser
5 Maximiser
6 Lever
7 Envoyer vers ...
8 Ombrer
9 Coller

$set 17 #Workspace

1 Bureau %d
2 Bureaux
3 Nouveau bureau
4 Supprimer le dernier

$set 18 #bsetroot

1 %s: Erreur: il faut prciser: -solid, -mod, -gradient\n
3 %s 2.0: (c) 1997-2000 Brad Hughes\n\n\
-display <chane>        	connexion  l'cran\n\
-mod <x> <y>             	schma\n\
-foreground, -fg <couleur> 	couleur au premier plan\n\
-background, -bg <couleur> 	couleur au second plan\n\n\
-gradient <texture>      	texture du dgrad\n\
-from <couleur>            	couleur de dpart du dgrad\n\
-to <couleur>              	couleur d'arriv du dgrad\n\n\
-solid <couleur>           	couleur pleine\n\n\
-help                    	affiche ce texte d'aide et quitte\n

$set 19 #main

1 Erreur: '-display' ncessite un argument\n
11 Erreur: '-rc' ncessite un argument\n
12 Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
-display <chane>\t\tutilise la connexion  l'affichage.\n\
-rc <chane>\t\t\tutilise un autre fichier de configuration.\n\
-version\t\t\taffiche la version et quitte.\n\
-info\t\t\t\tdisplay some useful information.\n\
-log <filename>\t\t\tlog output to file.\n\
-help\t\t\t\taffiche ce texte d'aide et quitte.\n\n

==> fluxbox-1.0rc2.tar.bz2: fluxbox-1.0rc2/nls/fr_FR/Translation.m <==
$ codeset=ISO-8859-15

$set 1 #Align

1 En bas au centre
2 En bas  gauche
3 En bas  droite
4 Horizontal
6 A gauche en bas
7 A gauche au centre
8 A gauche en Haut
11 A droite en bas
12 A droite au centre
13 A droite en haut
14 En haut au centre
15 En haut  gauche
16 En haut  droite
17 Vertical

$set 2 #BaseDisplay


$set 3 #Common

2 Masquer automatiquement

$set 4 #Configmenu

2 Premier plan automatique
4 Cliquer pour converger
7 Convergence de la dernire fentre
8 Mode de convergence
9 Convergence de la nouvelle fentre
10 Maximization complte
11 Lissage d'images
12 Dplacement opaque des fentres
13 Focus semi-stupide
14 Convergence souple
15 Workspace Warping

$set 5 #Ewmh


$set 6 #FbTkError


$set 7 #Fluxbox


$set 8 #Gnome


$set 9 #Keys


$set 10 #Menu

3 Sortie
4 Icones
7 Disposition
9 Redmarrer

$set 11 #Remember


$set 12 #Screen

2 L: %4d x H: %4d

$set 13 #Slit

4 Orientation du Slit
7 Disposition du Slit
8 Slit

$set 14 #Toolbar

1 Bptme du bureau courant
10 Disposition de la barre d'outils
11 Barre d'outils

$set 15 #Window

1 Inconnu

$set 16 #Windowmenu

1 Fermer
2 Iconifier
4 Baisser
5 Maximiser
6 Lever
7 Envoyer vers ...
8 Ombrer
9 Coller

$set 17 #Workspace

1 Bureau %d
2 Bureaux
3 Nouveau bureau
4 Supprimer le dernier

$set 18 #fbsetroot

1 Erreur: il faut prciser: -solid, -mod, -gradient\n
3 -display <chane>        	connexion  l'cran\n\
-mod <x> <y>             	schma\n\
-foreground, -fg <couleur> 	couleur au premier plan\n\
-background, -bg <couleur> 	couleur au second plan\n\n\
-gradient <texture>      	texture du dgrad\n\
-from <couleur>            	couleur de dpart du dgrad\n\
-to <couleur>              	couleur d'arriv du dgrad\n\n\
-solid <couleur>           	couleur pleine\n\n\
-help                    	affiche ce texte d'aide et quitte\n

$set 19 #main

1 Erreur: '-display' ncessite un argument
11 Erreur: '-rc' ncessite un argument
13 Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
-display <chane>\t\tutilise la connexion  l'affichage.\n\
-rc <chane>\t\t\tutilise un autre fichier de configuration.\n\
-version\t\t\taffiche la version et quitte.\n\
-info\t\t\t\tdisplay some useful information.\n\
-log <filename>\t\t\tlog output to file.\n\
-help\t\t\t\taffiche ce texte d'aide et quitte.\n\n
